@@ -366,7 +366,10 @@ class LowRankRegressor(BaseEstimator, RegressorMixin):
         
         dim = self.K_X_.shape[0]
         inv_dim = dim**(-1)
-        alpha = dim*self.tikhonov_reg
+        try:
+            alpha = dim*self.tikhonov_reg
+        except AttributeError:
+            alpha = np.sqrt(dim) #dim*reg with reg~1/sqrt(dim)
         K = inv_dim*(self.K_Y_@self.K_X_)
         tikhonov = aslinearoperator(diags(np.ones(dim, dtype=self.K_X_.dtype)*alpha))
         _S = eigs(K, k, aslinearoperator(self.K_X_) + tikhonov, return_eigenvectors = False)
